==> Totem%20Utils-1.1.2-1.21-sources.jar: CCPCT/TotemUtils/util/Packets.java <==
package CCPCT.TotemUtils.util;

import it.unimi.dsi.fastutil.ints.Int2ObjectOpenHashMap;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.event.lifecycle.v1.ClientTickEvents;
import net.minecraft.class_1703;
import net.minecraft.class_1713;
import net.minecraft.class_1799;
import net.minecraft.class_2596;
import net.minecraft.class_2813;
import net.minecraft.class_2868;
import net.minecraft.class_310;
import net.minecraft.class_634;
import java.util.ArrayList;

public class Packets implements ClientModInitializer {
    private static final ArrayList<class_2596<?>> packetsToSend = new ArrayList<>();

    @Override
    public void onInitializeClient() {
        ClientTickEvents.END_CLIENT_TICK.register(client -> {
            if (packetsToSend.isEmpty()){
                return;
            }
            if (packetsToSend.getFirst() == null){
                packetsToSend.removeFirst();
                return;
            }

            sendPacket(packetsToSend.getFirst(),false);

            packetsToSend.removeFirst();
        });
    }

    public static boolean isQueueEmpty(){
        return packetsToSend.isEmpty();
    }

    public static void sendPacket(class_2596<?> packet,boolean delay) {
        class_634 networkHandler = class_310.method_1551().method_1562();
        if (networkHandler == null) return;
        if (delay) {
            packetsToSend.add(packet);
        } else {
            networkHandler.method_52787(packet);
        }
    }

    //packet methods
//    public static void clickItem(int slot, ItemStack holding, boolean delay) {
//        if (MinecraftClient.getInstance().player == null) return;
//        ScreenHandler screenHandler = MinecraftClient.getInstance().player.currentScreenHandler;
//        sendPacket(new ClickSlotC2SPacket(
//                screenHandler.syncId,
//                screenHandler.getRevision(),
//                slot,
//                0,
//                SlotActionType.PICKUP,
//                holding,
//                new Int2ObjectOpenHashMap<>()
//        ),delay);
//    }

    public static void swapItem(int slot, int to, boolean delay) {
        if (class_310.method_1551().field_1724 == null) return;
        class_1703 screenHandler = class_310.method_1551().field_1724.field_7512;
        sendPacket(new class_2813(
                screenHandler.field_7763,
                screenHandler.method_37421(),
                slot,
                to,
                class_1713.field_7791,
                class_1799.field_8037,
                new Int2ObjectOpenHashMap<>()
        ),delay);
    }


    public static void selectHotbarSlot(int slot, boolean delay) {
        // use protocal number
        if (slot < 0 || slot > 8) return; // validate slot
        sendPacket(new class_2868(slot),delay);

    }

    public static void sendNull(){
        sendPacket(null,true);
    }
}

==> Totem%20Utils-1.2.0-1.21-sources.jar: CCPCT/TotemUtils/util/Packets.java <==
package CCPCT.TotemUtils.util;

import it.unimi.dsi.fastutil.ints.Int2ObjectOpenHashMap;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.event.lifecycle.v1.ClientTickEvents;
import net.minecraft.class_1703;
import net.minecraft.class_1713;
import net.minecraft.class_1799;
import net.minecraft.class_2596;
import net.minecraft.class_2813;
import net.minecraft.class_2868;
import net.minecraft.class_310;
import net.minecraft.class_634;
import java.util.ArrayList;

public class Packets implements ClientModInitializer {
    private static final ArrayList<class_2596<?>> packetsToSend = new ArrayList<>();

    @Override
    public void onInitializeClient() {
        ClientTickEvents.END_CLIENT_TICK.register(client -> {
            if (packetsToSend.isEmpty()){
                return;
            }
            if (packetsToSend.getFirst() == null){
                packetsToSend.removeFirst();
                return;
            }

            sendPacket(packetsToSend.getFirst(),false);

            packetsToSend.removeFirst();
        });
    }

    public static boolean isQueueEmpty(){
        return packetsToSend.isEmpty();
    }

    public static void sendPacket(class_2596<?> packet,boolean delay) {
        class_634 networkHandler = class_310.method_1551().method_1562();
        if (networkHandler == null) return;
        if (delay) {
            packetsToSend.add(packet);
        } else {
            networkHandler.method_52787(packet);
        }
    }

    // packet methods
    public static void clickItem(int slot, class_1799 holding, boolean delay) {
        if (class_310.method_1551().field_1724 == null) return;
        class_1703 screenHandler = class_310.method_1551().field_1724.field_7512;
        sendPacket(new class_2813(
                screenHandler.field_7763,
                screenHandler.method_37421(),
                slot,
                0,
                class_1713.field_7790,
                holding,
                new Int2ObjectOpenHashMap<>()
        ),delay);
    }

    public static void doubleClickItem(int slot, class_1799 holding, boolean delay) {
        if (class_310.method_1551().field_1724 == null) return;
        class_1703 screenHandler = class_310.method_1551().field_1724.field_7512;
        sendPacket(new class_2813(
                screenHandler.field_7763,
                screenHandler.method_37421(),
                slot,
                0,
                class_1713.field_7793,
                holding,
                new Int2ObjectOpenHashMap<>()
        ),delay);
    }

    public static void swapItem(int slot, int to, boolean delay) {
        if (class_310.method_1551().field_1724 == null) return;
        class_1703 screenHandler = class_310.method_1551().field_1724.field_7512;
        sendPacket(new class_2813(
                screenHandler.field_7763,
                screenHandler.method_37421(),
                slot,
                to,
                class_1713.field_7791,
                class_1799.field_8037,
                new Int2ObjectOpenHashMap<>()
        ),delay);
    }


    public static void selectHotbarSlot(int slot, boolean delay) {
        // use protocal number
        if (slot < 0 || slot > 8) return; // validate slot
        sendPacket(new class_2868(slot),delay);

    }
    public static void sendNull(int n){
        for (int i=0;i<n;i++){
            sendPacket(null,true);
        }
    }

    public static void sendNull(){
        sendPacket(null,true);
    }
}
